==> dyedvoid-1.0.3%2Bmc1.21.1-sources.jar: archives/tater/dyedvoid/EndVoidBlock.java <==
package archives.tater.dyedvoid;

import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2586;
import net.minecraft.class_2640;
import net.minecraft.class_2680;
import org.jetbrains.annotations.Nullable;


public class EndVoidBlock extends VoidBlock implements class_2343 {
    public EndVoidBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11455;
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new EndVoidBlockEntity(pos, state);
    }

    public static class EndVoidBlockEntity extends class_2640 {
        public EndVoidBlockEntity(class_2338 pos, class_2680 state) {
            super(DyedVoidBlocks.END_VOID_BLOCK_ENTITY, pos, state);
        }

        @Override
        public boolean method_11400(class_2350 direction) {
            if (field_11863 == null) return true;
            return class_2248.method_9607(this.method_11010(), field_11863, this.method_11016(), direction, this.method_11016().method_10093(direction));
        }
    }

    public static void tryCraft(class_1297 entity) {
        if (!(entity instanceof class_1542 itemEntity)) return;
        var stack = itemEntity.method_6983();
        if (!stack.method_31574(DyedVoidItems.BLACK_VOID)) return;
        itemEntity.method_6979(new class_1799(DyedVoidItems.END_VOID, stack.method_7947()));
    }
}

==> dyedvoid-1.0.4%2Bmc1.21.10-sources.jar: archives/tater/dyedvoid/EndVoidBlock.java <==
package archives.tater.dyedvoid;

import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2586;
import net.minecraft.class_2640;
import net.minecraft.class_2680;
import org.jetbrains.annotations.Nullable;


public class EndVoidBlock extends VoidBlock implements class_2343 {
    public EndVoidBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11455;
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new EndVoidBlockEntity(pos, state);
    }

    public static class EndVoidBlockEntity extends class_2640 {
        public EndVoidBlockEntity(class_2338 pos, class_2680 state) {
            super(DyedVoidBlocks.END_VOID_BLOCK_ENTITY, pos, state);
        }

        @Override
        public boolean method_11400(class_2350 direction) {
            if (field_11863 == null) return true;
            return class_2248.method_9607(this.method_11010(), this.field_11863.method_8320(this.method_11016().method_10093(direction)), direction);
        }
    }

    public static void tryCraft(class_1297 entity) {
        if (!(entity instanceof class_1542 itemEntity)) return;
        var stack = itemEntity.method_6983();
        if (!stack.method_31574(DyedVoidItems.BLACK_VOID)) return;
        itemEntity.method_6979(new class_1799(DyedVoidItems.END_VOID, stack.method_7947()));
    }
}
